%define name skencil
%define version 0.6.18
%define svn 695
%if %svn
%define release %mkrel 0.%svn.4
# needed for "correct all the bugs the install script introduces" below because
# skencil SVN still defines itself as 0.6.17 internally
%define internalversion 0.6.17
%else
%define release %mkrel 1
%endif

Name:		%name
Summary:	Drawing tool
Version:	%version
Release:	%release
%if %svn
Source0: 	%{name}-0.6-%{svn}.tar.bz2
%else
Source0:	http://download.sourceforge.net/sketch/%{name}-%{version}.tar.bz2
%endif
# From Fedora
Source1:	skencil-logo.png
Patch1:		sketch-0.6.15-tk-include-path.patch
# Fix font issues: from Bernhard Reiter (bug #20899)
Patch2:		skencil-0.6.17-fonts.patch
# Allow build with TCL/TK 8.5 (AdamW)
Patch3:		skencil-0.6.17-tcl85.patch
Group:		Graphics
BuildRequires:	X11-devel tcl tcl-devel tk tk-devel
BuildRequires:	python-devel
# required for sys.lib
BuildRequires:	python-imaging-devel
BuildRequires:	sed ImageMagick
License:	GPL
BuildRoot:	%_tmppath/%name-%version-%release-root
Requires:	tkinter
Requires:	python-imaging
Requires:	python-pyxml
URL:		http://www.skencil.org/

%description
Drawing tool written in Python, using Bezier curves.

%prep

%if %svn
%setup -q -n %{name}-0.6
%else
%setup -q -n %{name}-%{version}
%endif
%patch1 -p1 -b .tk-include-path
# Don't use suffix for patch2 as the files would end up in the package
%patch2 -p1
%patch3 -p1 -b .tcl85

# AdamW: fix build with X.org 7.x
perl -pi -e 's,/usr/X11R6,/usr,g' Pax/Setup.in
perl -pi -e 's,/usr/X11R6,/usr,g' setup.py
perl -pi -e 's,/usr/X11R6,/usr,g' Sketch/Modules/Setup.in
# AdamW: fix build on x86-64
perl -pi -e 's,\$\(exec_prefix\)/lib,%_libdir,g' Pax/Makefile.pre.in
perl -pi -e 's,\$\(exec_installdir\)/lib,%_libdir,g' Pax/Makefile.pre.in
perl -pi -e 's,\$\(exec_prefix\)/lib,%_libdir,g' Filter/Makefile.pre.in
perl -pi -e 's,\$\(exec_installdir\)/lib,%_libdir,g' Filter/Makefile.pre.in
perl -pi -e 's,\$\(exec_prefix\)/lib,%_libdir,g' Sketch/Modules/Makefile.pre.in
perl -pi -e 's,\$\(exec_installdir\)/lib,%_libdir,g' Sketch/Modules/Makefile.pre.in
perl -pi -e 's,/usr/lib,%_libdir,g' Pax/Setup.in
perl -pi -e 's,/usr/lib,%_libdir,g' setup.py
perl -pi -e 's,lib/python,%_lib/python,g' setup.py
sed -i s/\'lib\'/\'%_lib\'/ setup.py

%build

# AdamW: --python-setup is needed or else it looks for the file in /usr/lib on x86-64
./setup.py configure --with-nls --python-setup=%py_platlibdir/config/Setup
./setup.py build

%install
rm -fr %buildroot

./setup.py install --prefix=$RPM_BUILD_ROOT%{_prefix}

# (fg) Install program is shitty to say the least, we have to substitute all
# occurences of RPM_BUILD_{ROOT,DIR} to void :(
# Geoff says that the following is too disgusting to watch and harmful
# for your health.

set +x
(
  cd $RPM_BUILD_ROOT

  for i in `find -type f`; do
    perl -pi -e "s|$RPM_BUILD_ROOT||" $i;
    perl -pi -e "s|$RPM_BUILD_DIR||" $i;
  done
)
set -x

# Now correct all the bugs the install script introduces:
%if %svn
cp Sketch/Modules/*so $RPM_BUILD_ROOT%{_libdir}/%{name}-%{internalversion}/Sketch/Modules
cp Filter/*so Pax/*so $RPM_BUILD_ROOT%{_libdir}/%{name}-%{internalversion}/Lib/
%else
cp Sketch/Modules/*so $RPM_BUILD_ROOT%{_libdir}/%{name}-%{version}/Sketch/Modules
cp Filter/*so Pax/*so $RPM_BUILD_ROOT%{_libdir}/%{name}-%{version}/Lib/
%endif

# icons
mkdir -p %buildroot{%_liconsdir,%_miconsdir}
mkdir -p %buildroot%{_iconsdir}/hicolor/{48x48,32x32,16x16}/apps
convert -scale 48x48 %SOURCE1 %buildroot%_liconsdir/%{name}.png
convert -scale 32x32 %SOURCE1 %buildroot%_iconsdir/%{name}.png
convert -scale 16x16 %SOURCE1 %buildroot%_miconsdir/%{name}.png
convert -scale 48x48 %SOURCE1 %buildroot%_iconsdir/hicolor/48x48/apps/%{name}.png
convert -scale 32x32 %SOURCE1 %buildroot%_iconsdir/hicolor/32x32/apps/%{name}.png
convert -scale 16x16 %SOURCE1 %buildroot%_iconsdir/hicolor/16x16/apps/%{name}.png

# menu
mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
cat > $RPM_BUILD_ROOT%{_datadir}/applications/mandriva-%{name}.desktop << EOF
[Desktop Entry]
Encoding=UTF-8
Name=Skencil
Comment=Drawing tool
Exec=%{_bindir}/%{name} %f
Icon=%{name}
Terminal=false
Type=Application
StartupNotify=true
MimeType=image/x-sk
Categories=Graphics;VectorGraphics;X-MandrivaLinux-Multimedia-Graphics
EOF

%find_lang --all-name %name.lang

%post
%update_icon_cache hicolor
%update_menus
%update_desktop_database
%postun
%clean_icon_cache hicolor
%clean_menus
%clean_desktop_database

%clean
rm -fr %buildroot

%files -f %name.lang
%defattr(-,root,root,0755)
%doc Doc/* 
%if %svn
%{_libdir}/%{name}-%{internalversion}
%else
%{_libdir}/%{name}-%{version}
%endif
%{_bindir}/*
%_iconsdir/hicolor/16x16/apps/%{name}.png
%_iconsdir/hicolor/32x32/apps/%{name}.png
%_iconsdir/hicolor/48x48/apps/%{name}.png
%_liconsdir/%{name}.png
%_iconsdir/%{name}.png
%_miconsdir/%{name}.png
%_datadir/applications/mandriva-%{name}.desktop


%changelog
* Tue May 15 2007 Adam Williamson <awilliamson@mandriva.com> 0.6.18-0.695.4mdv2007.1
+ Revision: 27114
- correct font patch for Utopia and Charter fonts

* Wed May 09 2007 Adam Williamson <awilliamson@mandriva.com> 0.6.18-0.695.3mdv2008.0
+ Revision: 25772
- update font patch to include /usr/share/fonts/Type1

* Mon May 07 2007 Adam Williamson <awilliamson@mandriva.com> 0.6.18-0.695.2mdv2008.0
+ Revision: 24904
- add fix for default ruler font to font patch
- don't use suffix for font fix patch to avoid files turning up in package
- more elegant x86-64 fix substitutions (use %%_lib not ifarch)

* Thu May 03 2007 Adam Williamson <awilliamson@mandriva.com> 0.6.18-0.695.1mdv2008.0
+ Revision: 20835
- restore a workaround that turns out to be needed after all
- oops, fix menu entry generation
- generate and package XDG menu entry
- generate and package fd.o and MDV icons
- drop no longer needed workaround for old installer bug
- Fix build for modern X.org and x86_64
- Update and fix BuildRequires (tix is not needed)
- add Patch3 (allow build with Tcl/Tk 8.5)
- add Patch2 (fix fonts and locations, bug #20899)
- drop Source2 (old menu file)
- Add Source1 (icon, from Fedora)
- SVN branch 0.6 (for build fixes)


* Wed May 10 2006 Jerome Soyer <saispo@mandriva.org> 0.6.17-2mdk
- Ooops, fix BuildRequires

* Wed May 10 2006 Jerome Soyer <saispo@mandriva.org> 0.6.17-1mdk
- New release 0.6.17
- Remove unneeded patch
- Clean spec
- Close and fix bug #20673

* Tue Jan 03 2006 Oden Eriksson <oeriksson@mandriva.com> 0.6.16-5mdk
- rebuilt against soname aware deps (tcl/tk)
- fix deps

* Sat Mar 19 2005 Frederic Lepied <flepied@mandrakesoft.com> 0.6.16-4mdk
- requires python-pyxml (bug #14766)

* Wed Mar 09 2005 Frederic Lepied <flepied@mandrakesoft.com> 0.6.16-3mdk
- don't use an internal python-imaging. This fixes image loading.
- fixed URL

* Wed Dec 15 2004 Daniel Burr <daniel@tmq.com.au> 0.6.16-2mdk
- Update paxtkinter to work with python 2.4

* Wed May 05 2004 Frederic Lepied <flepied@mandrakesoft.com> 0.6.16-1mdk
- new name for sketch

* Wed Feb 18 2004 David Baudens <baudens@mandrakesoft.com> 0.6.16-0.pre2.3mdk
- Fix menu

* Fri Sep 26 2003 Gwenole Beauchesne <gbeauchesne@mandrakesoft.com> 0.6.16-0.pre2.2mdk
- lib64 fixes

* Wed Sep 17 2003 Lenny Cartier <lenny@mandrakesoft.com> 0.6.16-0.pre2.1mdk
- Fix Bug#4778 : update to 0.6.16pre2 reported by the author to work with latest python.

* Wed May 14 2003 Per yvind Karlsen <peroyvind@sintrax.net> 0.6.15-2mdk
- rebuild against tcl8.4

